#include "vector3.h"

Vector3::Vector3() {
	x = 0;
	y = 0;
	z = 0;
}

Vector3::Vector3(const Vector3 &b) {
	setXYZ(b.getX(), b.getY(), b.getZ());
}

Vector3::Vector3(GLfloat newX, GLfloat newY, GLfloat newZ) {
	setXYZ(newX, newY, newZ);
}

float Vector3::getMagnitude() const {
	return sqrt(getX()*getX() + getY()*getY() + getZ()*getZ());
}

float Vector3::dot(const Vector3 &b) const {
	return (getX()*b.getX() + getY()*b.getY() + getZ()*b.getZ());
}

Vector3 Vector3::cross(const Vector3 &b) const {
	GLfloat crossX = getY()*b.getZ() - getZ()*b.getY();
	GLfloat crossY = getZ()*b.getX() - getX()*b.getZ();
	GLfloat crossZ = getX()*b.getY() - getY()*b.getX();

	Vector3 result(crossX, crossY, crossZ);

	return result;
}

void Vector3::normalize() {
	float magnitude = getMagnitude();

	setXYZ(getX()/magnitude, getY()/magnitude, getZ()/magnitude);
}

void Vector3::translate(float deltaX, float deltaY, float deltaZ) {
	setXYZ(getX() + deltaX, getY() + deltaY, getZ() + deltaZ);
}

void Vector3::rotateX(float theta) {

}

void Vector3::rotateY(float theta) {

}

void Vector3::rotateZ(float theta) {

}

void Vector3::rotate(float theta, const Vector3 &axis) {

}

Vector3 Vector3::operator+(const Vector3 &b) const {
	Vector3 result(getX() + b.getX(), getY() + b.getY(), getZ() + b.getZ());

	return result;
}

Vector3 Vector3::operator-(const Vector3 &b) const {
	Vector3 result(getX() - b.getX(), getY() - b.getY(), getZ() - b.getZ());

	return result;
}

Vector3 Vector3::operator*(float b) const {
	Vector3 result(getX()*b, getY()*b, getZ()*b);

	return result;
}

Vector3 & Vector3::operator+=(const Vector3 &rhs) {
	setXYZ(getX() + rhs.getX(), getY() + rhs.getY(), getZ() + rhs.getZ());

	return *this;
}

Vector3 & Vector3::operator-=(const Vector3 &rhs) {
	setXYZ(getX() - rhs.getX(), getY() - rhs.getY(), getZ() - rhs.getZ());

	return *this;
}

Vector3 & Vector3::operator*=(float b) {
	setXYZ(getX()*b, getY()*b, getZ()*b);

	return *this;
}

Vector3 & Vector3::operator=(const Vector3 &rhs) {
	setXYZ(rhs.getX(), rhs.getY(), rhs.getZ());

	return *this;
}