#ifndef VECTOR3
#define VECTOR3

#include <math.h>
#include <GL/glut.h>

class Vector3 {
public:
	Vector3();
	Vector3(const Vector3 &b);
	Vector3(GLfloat newX, GLfloat newY, GLfloat newZ);

	GLfloat getX() const {return x;}
	GLfloat getY() const {return y;}
	GLfloat getZ() const {return z;}

	float dot(const Vector3 &b) const;
	Vector3 cross(const Vector3 &b) const;

	float getMagnitude() const;

	void setX(GLfloat newX) {x = newX;}
	void setY(GLfloat newY) {y = newY;}
	void setZ(GLfloat newZ) {z = newZ;}

	void setXYZ(GLfloat newX, GLfloat newY, GLfloat newZ) {setX(newX); setY(newY); setZ(newZ);}

	void normalize();

	void translate(float deltaX, float deltaY, float deltaZ);

	void rotateX(float theta);
	void rotateY(float theta);
	void rotateZ(float theta);

	void rotate(float theta, const Vector3 &axis);

	Vector3 operator+(const Vector3 &b) const;
	Vector3 operator-(const Vector3 &b)  const;
	Vector3 operator*(float b)  const;

	Vector3 & operator+=(const Vector3 &rhs);
	Vector3 & operator-=(const Vector3 &rhs);
	Vector3 & operator*=(float b);

	Vector3 & operator=(const Vector3 &rhs);

private:
	GLfloat x;
	GLfloat y;
	GLfloat z;
};

#endif